@@ -1,6 +1,6 @@
 package XML::MyXML;
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
-$XML::MyXML::VERSION = '0.9405';
+$XML::MyXML::VERSION = '0.9406';
 use strict;
 use warnings;
 use Carp;
@@ -473,7 +473,7 @@ sub check_xml {
 
 
 package XML::MyXML::Object;
-$XML::MyXML::Object::VERSION = '0.9405';
+$XML::MyXML::Object::VERSION = '0.9406';
 use Carp;
 use Encode;
 use Scalar::Util qw/ weaken /;
@@ -566,10 +566,10 @@ sub path {
 }
 
 
-sub value {
+sub text {
 	my $self = shift;
-	my $flags = (@_ and ref $_[-1]) ? pop : {};
-	my $set_value = @_ ? (shift // '') : undef;
+	my $flags = (@_ and ref $_[-1]) ? pop() : {};
+	my $set_value = @_ ? defined $_[0] ? shift() : '' : undef;
 
 	if (! defined $set_value) {
 		my $value = '';
@@ -596,7 +596,7 @@ sub value {
 	}
 }
 
-*text = \&value;
+*value = \&text;
 
 
 sub attr {
@@ -717,7 +717,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.9405
+version 0.9406
 
 =head1 SYNOPSIS
 
